/*
** Module   : SchemaTrigger.java
** Abstract : Annotation used to declare Trigger Procedure related attributes.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 OM  20131128 Initial commit. Declares following elements: buffer, event, field, 
**                  overridable and hasOldBuffer.
*/
package com.goldencode.p2j.util;

import com.goldencode.p2j.persist.Buffer;
import com.goldencode.p2j.persist.trigger.DatabaseEventType;
import java.lang.annotation.*;

/**
 * Annotation definition to mark trigger trigger procedures in order to be dynamically
 * found and loaded at runtime.
 * This annotation stores attributes that were extracted from both database's .schema file
 * and from processed source AST file.
 */
@Target(ElementType.TYPE)           // Annotation can only be applied to classes.
@Retention(RetentionPolicy.RUNTIME) // Annotation will be accessible at runtime via reflection.
public @interface SchemaTrigger
{
   /**
    * The table for which this trigger handles the event.
    */
   Class<? extends Buffer> buffer();

   /** The database event to which this trigger responds to. */
   DatabaseEventType event();

   /** In the case of ASSIGN, the field that will trigger the me, otherwise empty. */
   String field() default "";

   /** Allows this schema trigger to be overridden by session triggers. */
   boolean overrideable();

   /**
    * In the case of WRITE and ASSIGN triggers, the TRIGGER PROCEDURE may declare a 'parameter'
    * that will contain the old value before change.
    */
   boolean hasOldBuffer();
}

